<?php
/**
 * Phoo Gadget
 *
 * @category   GadgetAdmin
 * @package    Phoo
 * @author     Jonathan Hernandez <ion@suavizado.com>
 * @author     Pablo Fischer <pablo@pablo.com.mx>
 * @author     Raul Murciano <raul@murciano.net>
 * @copyright   2004-2024 Jaws Development Group
 * @license    http://www.gnu.org/copyleft/gpl.html
 */
class Phoo_Actions_Admin_Upload extends Phoo_Actions_Admin_Default
{
    /**
     * Displays a form for adding new images.
     *
     * @access  public
     * @return  string   XHTML template content
     */
    function UploadPhotos()
    {
        $this->gadget->CheckPermission('AddPhotos');
        $this->AjaxMe('script.js');

        $album = $this->gadget->request->fetch('album', 'get');

        $model = $this->gadget->model->load('Albums');
        $tpl = $this->gadget->template->loadAdmin('UploadPhotos.html');
        $tpl->SetBlock('upload');
        $tpl->SetVariable('menubar', $this->MenuBar('UploadPhotos'));

        include_once ROOT_JAWS_PATH . 'include/Jaws/Widgets/FieldSet.php';
        $phooFieldset = new Jaws_Widgets_FieldSet($this::t('UPLOAD_PHOTOS'));
        $phooFieldset->SetDirection('vertical');
        $phooFieldset->SetId('phoo_fieldset');
        $phooForm =& Piwi::CreateWidget('Form',
            BASE_SCRIPT . '?reqGadget=Phoo',
            'post',
            'multipart/form-data');
        $phooForm->Add(Piwi::CreateWidget('HiddenEntry', 'MAX_FILE_SIZE', '15000000'));
        $phooForm->Add(Piwi::CreateWidget('HiddenEntry', 'reqGadget', 'Phoo'));
        $phooForm->Add(Piwi::CreateWidget('HiddenEntry', 'reqAction', 'UploadPhotosStep2'));

        $albumcombo =& Piwi::CreateWidget('Combo', 'album', $this::t('ALBUM'));
        $albums = $model->GetAlbums('name', 'ASC');
        if (!Jaws_Error::IsError($albums) && !empty($albums)) {
            $date = Jaws_Date::getInstance();
            foreach ($albums as $a) {
                // FIXME: Ugly hack to add title to albumcombo
                $o =& Piwi::CreateWidget('ComboOption', $a['id'], $a['name']);
                $o->SetTitle($this::t('NUM_PHOTOS_ALBUM', $a['howmany']) . ' / '.
                $this::t('ALBUM_CREATION_DATE', $date->Format($a['createtime'])));
                $albumcombo->_options[$a['id']] = $o;
            }
        }
        $albumcombo->SetDefault((int)$album);
        $phooFieldset->Add($albumcombo);
        for ($i = 1; $i <= 5; $i++) {
            $imageEntry =& Piwi::CreateWidget('FileEntry', 'photo'.$i);
            $imageEntry->SetTitle($this::t('PHOTO').' '.$i);
            $phooFieldset->Add($imageEntry);
        }

        $addEntryButton =& Piwi::CreateWidget('Button', 'addEntryButton', $this::t('ADD_ANOTHER_PHOTO'), STOCK_ADD);
        $addEntryButton->AddEvent(ON_CLICK, "addEntry('" . $this::t('PHOTO') . "');");
        $addEntryUrl = '<span id="phoo_addentry6"><div><a href="#" onclick="addEntry(\'' . $this::t('PHOTO') . '\');">' . $this::t('ADD_ANOTHER_PHOTO') . '</a></div></span>';
        $addEntryArea = '<span id="phoo_addentry6"><div>' . $addEntryButton->Get() . '</div></span>';
        $addEntry =& Piwi::CreateWidget('StaticEntry', $addEntryArea);
        $phooFieldset->Add($addEntry);
        $buttonbox =& Piwi::CreateWidget('HBox');
        $buttonbox->SetStyle(Jaws::t('LANG_DIRECTION')=='rtl'?'float: left;' : 'float: right;'); //hig style
        $submit =& Piwi::CreateWidget('Button', 'uploadphotos', $this::t('UPLOAD_PHOTOS'), STOCK_SAVE);
        $submit->SetSubmit();
        $buttonbox->Add($submit);
        $phooForm->Add($phooFieldset);
        $phooForm->Add($buttonbox);

        $tpl->SetVariable('form', $phooForm->Get());

        $tpl->ParseBlock('upload');
        return $tpl->Get();
    }

    /**
     * Saves a new image using input data from UploadPhotos
     * If required any new albums will be created
     *
     * @access  public
     * @see Phoo::UploadPhotos()
     * @see Phoo_Model::AddEntryToAlbum()
     * @see Phoo_Model::AddCategoryToEntry()
     * @see Phoo_Model::NewAlbum()
     */
    function UploadPhotosStep2()
    {
        $uModel = $this->gadget->model->loadAdmin('Upload');
        $pModel = $this->gadget->model->loadAdmin('Photos');
        $aModel = $this->gadget->model->load('Albums');
        $files = $uModel->UnpackFiles($_FILES);

        $album   = (int)$this->gadget->request->fetch('album', 'post');
        $extra_params = $this->gadget->request->fetch('extra_params', 'post');

        $failures = array();
        $uploadedImages = array();
        $album_data = $aModel->getAlbumInfo($album);
        if (Jaws_Error::IsError($album_data) || empty($album_data)) {
            $this->gadget->session->push($album_data->getMessage());
            return Jaws_Header::Location(BASE_SCRIPT . '?reqGadget=Phoo');
        }
        for ($i = 1; $i <= count($files); $i++) {
            if (!isset($files['photo'.$i])) {
                continue;
            }

            $filename = $files['photo'.$i]['name'];
            if (!empty($filename)) {
                $exploded = explode('.', $filename);
                $ext  = array_pop($exploded);
                $name = basename($filename, '.'.$ext);
                $id = $pModel->NewEntry(0, $files['photo'.$i], $name, '', true, $album_data);
                if (!Jaws_Error::IsError($id)) {
                    $uploadedImages[] = $id;
                } else {
                    $failures[] = $this::t('UPLOAD_FAILURE').' <strong>'.$name.'.'.$ext.'</strong>';
                }
            }
        }

        // Assign to album
        if (count($uploadedImages) > 0) {
            foreach ($uploadedImages as $img) {
                $res = $pModel->AddEntryToAlbum($img, $album);
                if (Jaws_Error::IsError($res)) {
                    ///FIXME: This is a unacceptable solution
                    return Jaws_Header::Location(BASE_SCRIPT . '?reqGadget=Phoo');
                }
            }
        }

        $this->gadget->session->failures = $failures;
        if (empty($extra_params)) {
            return Jaws_Header::Location(BASE_SCRIPT . '?reqGadget=Phoo&album=' . $album);
        } else {
            return Jaws_Header::Location(BASE_SCRIPT . '?reqGadget=Phoo&reqAction=BrowsePhoo&album=' . $album . html_entity_decode($extra_params));
        }

    }

}